==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortHttpStatusFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortHttpStatusFluentImpl<A extends HTTPFaultInjectionAbortHttpStatusFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortHttpStatusFluent<A>{
  public HTTPFaultInjectionAbortHttpStatusFluentImpl() {
  }
  public HTTPFaultInjectionAbortHttpStatusFluentImpl(HTTPFaultInjectionAbortHttpStatus instance) {
    this.withHttpStatus(instance.getHttpStatus()); 
  }
  private Integer httpStatus;
  public Integer getHttpStatus() {
    return this.httpStatus;
  }
  public A withHttpStatus(Integer httpStatus) {
    this.httpStatus=httpStatus; return (A) this;
  }
  public Boolean hasHttpStatus() {
    return this.httpStatus != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPFaultInjectionAbortHttpStatusFluentImpl that = (HTTPFaultInjectionAbortHttpStatusFluentImpl) o;
    if (httpStatus != null ? !httpStatus.equals(that.httpStatus) :that.httpStatus != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpStatus,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpStatus != null) { sb.append("httpStatus:"); sb.append(httpStatus); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortHttpStatusFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortHttpStatusFluentImpl<A extends HTTPFaultInjectionAbortHttpStatusFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortHttpStatusFluent<A>{
  public HTTPFaultInjectionAbortHttpStatusFluentImpl() {
  }
  public HTTPFaultInjectionAbortHttpStatusFluentImpl(HTTPFaultInjectionAbortHttpStatus instance) {
    if (instance != null) {
      this.withHttpStatus(instance.getHttpStatus());
    }
  }
  private Integer httpStatus;
  public Integer getHttpStatus() {
    return this.httpStatus;
  }
  public A withHttpStatus(Integer httpStatus) {
    this.httpStatus=httpStatus; return (A) this;
  }
  public Boolean hasHttpStatus() {
    return this.httpStatus != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortHttpStatusFluentImpl that = (HTTPFaultInjectionAbortHttpStatusFluentImpl) o;
    if (!java.util.Objects.equals(httpStatus, that.httpStatus)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpStatus,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpStatus != null) { sb.append("httpStatus:"); sb.append(httpStatus); }
    sb.append("}");
    return sb.toString();
  }
  
}
